pub struct DataChunk {
pub size: u32,
pub data: Vec<u8>,
}Fields
size: u32data: Vec<u8>Trait Implementations
Sourceimpl BinRead for DataChunk
impl BinRead for DataChunk
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_options: &ReadOptions,
__binrw_generated_var_arguments: Self::Args,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_options: &ReadOptions, __binrw_generated_var_arguments: Self::Args, ) -> BinResult<Self>
Read
Self from the reader using the given ReadOptions and
arguments.Sourcefn read<R>(reader: &mut R) -> Result<Self, Error>
fn read<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments.Sourceimpl BinWrite for DataChunk
impl BinWrite for DataChunk
Sourcetype Args = ()
type Args = ()
The type of arguments needed to be supplied in order to write this type, usually a tuple. Read more
Sourcefn write_options<W: Write + Seek>(
&self,
__binrw_generated_var_writer: &mut W,
__binrw_generated_var_options: &WriteOptions,
__binrw_generated_var_arguments: Self::Args,
) -> BinResult<()>
fn write_options<W: Write + Seek>( &self, __binrw_generated_var_writer: &mut W, __binrw_generated_var_options: &WriteOptions, __binrw_generated_var_arguments: Self::Args, ) -> BinResult<()>
Write the type to a writer, given the options on how to write it and the type-specific
arguments
impl StructuralPartialEq for DataChunk